Icon Library is a Python 2 application that makes it easy to:
* view complete icon sets
* search icon sets
* export icon sets to HTML
* check which icon names comply with the freedesktop.org Standard Icon Naming Specification
* compare icons against a range of background colours

NOTE: This application was originally released by Matthew McGowan <matthew.joseph.mcgowan@gmail.com> under a LGPLv3 license. I have simply made a few changes and prepared it for packaging. See https://launchpad.net/icon-library.